/*
 * \brief  Client-side interface of the Hello service
 * \author Björn Döbel
 * \date   2008-03-20
 */

/*
 * Copyright (C) 2008-2009
 * Genode Labs, Feske & Helmuth Systementwicklung GbR
 *
 * This file is part of the Genode OS framework, which is distributed
 * under the terms of the GNU General Public License version 2.
 */

#ifndef _INCLUDE__HELLO_SESSION_H__CLIENT_H_
#define _INCLUDE__HELLO_SESSION_H__CLIENT_H_

#include <sampling_session/capability.h>
#include <base/ipc.h>
#include <base/printf.h>

using namespace Genode;

namespace Sampling {

	class Session_client : public Sampling::Session
	{
		protected:

			Genode::Msgbuf<256> _sndbuf, _rcvbuf;
			Genode::Ipc_client  _ipc_client;
		public:

			Session_client(Sampling::Session_capability cap)
			: _ipc_client(cap, &_sndbuf, &_rcvbuf) { }


			~Session_client() { }

			void say_hello()
			{
				PDBG("Saying Hello in sampling.");
				_ipc_client << SAY_HELLO << Genode::IPC_CALL;
			}
			
			int add(int a, int b)
			{
				int ret = 0;
				_ipc_client << ADD << a << b << Genode::IPC_CALL >> ret;
				return ret;
			}

			Genode::Dataspace_capability get_cap()
			{
				Dataspace_capability cap_val;
				PDBG("About to send capability");
				_ipc_client << NET_BUF << Genode::IPC_CALL >> cap_val;
				return cap_val;
			}

			void invalid_op()
			{
				PDBG("Calling server with invalid opcode.");
				_ipc_client << 1234 << Genode::IPC_CALL;
			}
	};
}

#endif /* _INCLUDE__HELLO_SESSION_H__CLIENT_H_ */
