/*
 * \brief  Server-side interface of the Hello service
 * \author Björn Döbel
 * \date   2008-03-20
 */

/*
 * Copyright (C) 2008-2009
 * Genode Labs, Feske & Helmuth Systementwicklung GbR
 *
 * This file is part of the Genode OS framework, which is distributed
 * under the terms of the GNU General Public License version 2.
 */

#ifndef _INCLUDE__HELLO_SESSION_H__SERVER_H_
#define _INCLUDE__HELLO_SESSION_H__SERVER_H_

#include <sampling_session/sampling_session.h>
#include <base/server.h>
#include <ram_session/connection.h>
#include <os/ram_dataspace.h>

using namespace Genode;

namespace Sampling {

	class Session_server : public Genode::Server_object,
	                       public Sampling::Session
	{
		public:
			
			
			Session_server()
			{
				PDBG("Creating session component."); 
			}

			int dispatch(int op, Genode::Ipc_istream &is,
			                     Genode::Ipc_ostream &os)
			{
				int a = 0;
				int b = 0;

				PDBG("dispatch op %d", op);

				switch(op) {

				case SAY_HELLO:
					say_hello();
					break;

				case ADD:
					is >> a;
					is >> b;
					PDBG("%d + %d ?", a, b);
					os << add(a, b);
					break;

				case NET_BUF:
					PDBG("NET_BUF dispatch\n");
					os << get_cap();
					break;

				default:
					PWRN("Invalid opcode.");
				}

				return 0;
			}
	};
}

#endif /* _INCLUDE__HELLO_SESSION_H__SERVER_H_ */
